#!/bin/ksh
#> This script will install Prospect 8.0 / Nortel MTX15 RP16 HF01 hotfix
#> Usage: install.sh {-help|-install|-uninstall}
#

InstallFileset='
vendor/Nortel/MSC/missingData/wm_AvailableData_pkg.sql
vendor/Nortel/MSC/NortelMTX.build
vendor/Nortel/MSC/part_maint/pop_subclass.sql
'

########################################################
# set paths and files

RELEASE="15.0.16.0.1"
SourceDir="${FLEXPM_HOME}/patches/${RELEASE}"
SourceDir1="${FLEXPM_HOME}/patches/${RELEASE}/nortel"
BackupDir1="${FLEXPM_HOME}/patches/${RELEASE}/backup/nortel"
INSTALLDIR=`pwd`

########################################################

### give help
  ToolName=`basename $0`
  runTime=`date '+%Y%m%d%H%M'`
  case $1 in
  -help|-usage)
    echo "${ToolName} usage information -- " 1>&2
    grep "^#> " $0 1>&2
    grep "^#>  \"" $0 1>&2
    exit 2
    ;;
  esac

# Check env settings

  if [ $# -ne 1 ]; then
    echo "Usage $0 {-help | -install | -uninstall}"
    exit;
  fi

  echo "Checking environment....."
  if ! [[ -d ${FLEXPM_HOME} ]]; then
    echo "Env variable FLEXPM_HOME must be set to appropriate dir before installation."
    exit;
  fi

  if [[ -z ${DB_CONNECT} ]]; then
     echo "Env variable DB_CONNECT must be set to approriate database connection values."
     exit;
  fi
  
  if [[ ${INSTALLDIR} != ${SourceDir} ]] ; then
     echo "This script should be run from ${SourceDir}"
     exit;
  fi
  
  echo "Checking diskspace required, including temporary spaces....."
  echo ""
  value2=`df -b . | tail -1 | awk '{print $2}'`
  value3=1000
  if [[ $value2 -ge $value3 ]]
   then
    echo ""
    echo " Diskspace check successful."
    echo ""
   else
    echo ""
    echo " Diskspace is not enough. You need at least approx. $value3 KB"
    echo " extra diskspace."
    exit 1;
  fi

# Source and destination directories

  case $1 in
  -install)
    echo "Installing patch..."

    # Updating the NortelMTX.build file
    chmod +w ${FLEXPM_HOME}/vendor/Nortel/MSC/NortelMTX.build
    cp ${SourceDir1}/vendor/Nortel/MSC/NortelMTX.build ${FLEXPM_HOME}/vendor/Nortel/MSC 

    echo "Registration of ${RELEASE} started."
    chmod +x $FLEXPM_HOME/pm/adm/register
    register start ${SourceDir1}/vendor/Nortel/MSC/NortelMTX.build
    [[ $? -ne 0 ]] && exit 1;

    echo "Files to be updated/added ..."
    for f in ${InstallFileset}
    do
        echo "${f}"
        if [[ -a ${FLEXPM_HOME}/${f} ]]; then
        # permissions
        chmod u+w ${FLEXPM_HOME}/${f}
		
        # backup
        cp -pf ${FLEXPM_HOME}/${f} ${BackupDir1}/${f}
        tar -cf backup.$runTime.tar ${BackupDir1}
		
        fi
        # install files
	cp -pf ${SourceDir1}/${f} ${FLEXPM_HOME}/${f}
		
	# permissions
	chmod u-w ${FLEXPM_HOME}/${f}
	chmod u+x ${FLEXPM_HOME}/${f}
    done

    echo "Running wm_AvailableData_pkg.sql..."
    sqlplus $DB_CONNECT @${FLEXPM_HOME}/vendor/Nortel/MSC/missingData/wm_AvailableData_pkg.sql

    echo "Running pop_subclass.sql..."
    sqlplus $DB_CONNECT @${FLEXPM_HOME}/vendor/Nortel/MSC/part_maint/pop_subclass.sql

    register complete ${SourceDir1}/vendor/Nortel/MSC/NortelMTX.build
   
    echo "Registration of ${RELEASE} completed."

    echo "Installation completed successfully."
    ;;

  -uninstall)

    echo " Contact Customer support for uninstallation of the patch "

    ;; 

  * )
    echo "Unknown option"
    echo "Usage: install.sh {-help|-install|-uninstall}"
    ;;
  esac
